pub struct AnimationSegment {
pub duration: f32,
pub anim_fn: for<'a> fn(&'a mut Ui, f32),
}Expand description
A single segment of the animation.
Defines the duration of a segment (in seconds), and a mutating function for
the [Ui]. See Animation for details on how to construct an animation function.
Example
// A simple animation that fades the prior value out, and the new value in.
// Has a total time of `0.4` seconds with each segment taking a respective `0.2` seconds each.
const FADE_OUT: AnimationSegment = AnimationSegment::new(0.2, |ui, normal| ui.set_opacity(1.0 - normal));
const FADE_IN: AnimationSegment = AnimationSegment::new(0.2, |ui, normal| ui.set_opacity(normal));
const ANIM: Animation = Animation::from_segments(FADE_OUT, FADE_IN);Fields
duration: f32The duration of the animation, in seconds.
anim_fn: for<'a> fn(&'a mut Ui, f32)The [Ui] mutating function for the given f32 normal.
Implementations